#!/usr/local/bin python3
# -*- coding: utf-8 -*-

"""
    created by iprobeyang@gmail.com 2021/4/27
"""
#
# import requests
#         # r = requests.get("https://www.baidu.com")
# res = requests.get('http://www.baidu.com').content
# print(res)
# import sys
#
# ds = {
#     "debug": 0
# }
# a = int(ds.get("debugs", 0))
# # print(a)
# if a == 0:
#     print("aaa")
# elif a == 1:
#     print("11111")
#
# default_level = 4
#
# def log(text, *args, level=0):
#     global default_level
#     if level >= default_level:
#         text = text % args
#         import time
#         timestamp = time.strftime("%Y-%m-%d %H:%M:%S", time.localtime())
#         import os
#         sys.stdout.write("FAST: %s (%d) - %s\n" % (timestamp, os.getpid(), text))
#         sys.stdout.flush()
# b = "test"
# c = {
#     "a":"w",
#     "b": "c"
# }
# log("tesi is %s, %r, %r", a, b, c, level=3)

if 0:
    print("a")

if 1:
    print("1")

if 2:
    print("2")

if []:
    print("ssss")